GatewayServerListener (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j

## Interface GatewayServerListener

- All Known Implementing Classes:
    DefaultGatewayServerListener, GatewayServer, JavaServer, PythonClient

      public interface GatewayServerListener

  A client can implement this listener to be notified of Gateway events.

- - ### Method Summary

    All Methods Instance Methods Abstract Methods
    Modifier and Type | Method and Description
    --- | ---
    `void` | `connectionError(java.lang.Exception e)`
    `void` | `connectionStarted(Py4JServerConnection gatewayConnection)`
    `void` | `connectionStopped(Py4JServerConnection gatewayConnection)`
    `void` | `serverError(java.lang.Exception e)` This method may be called concurrently with serverPostShutdown().
    `void` | `serverPostShutdown()` This method may be called concurrently with serverStopped() and serverError().
    `void` | `serverPreShutdown()`
    `void` | `serverStarted()`
    `void` | `serverStopped()` This method may be called concurrently with serverPostShutdown().

- - ### Method Detail

    - #### connectionError

          void connectionError(java.lang.Exception e)

    - #### connectionStarted

          void connectionStarted(Py4JServerConnection gatewayConnection)

    - #### connectionStopped

          void connectionStopped(Py4JServerConnection gatewayConnection)

    - #### serverError

          void serverError(java.lang.Exception e)

      This method may be called concurrently with serverPostShutdown().

      Typically a one thread calls shutdown() and then, the thread running the GatewayServer breaks from the connection accept loop.

    - #### serverPostShutdown

          void serverPostShutdown()

      This method may be called concurrently with serverStopped() and serverError().

      Typically a one thread calls shutdown() and then, the thread running the GatewayServer breaks from the connection accept loop.

    - #### serverPreShutdown

          void serverPreShutdown()

    - #### serverStarted

          void serverStarted()

    - #### serverStopped

          void serverStopped()

      This method may be called concurrently with serverPostShutdown().

      Typically a one thread calls shutdown() and then, the thread running the GatewayServer breaks from the connection accept loop.